@@ -20,11 +20,14 @@
 import c_evas
 
 from c_evas import Canvas, SmartObject, ClippedSmartObject, Rectangle, Line, \
-     Image, FilledImage, Gradient, Polygon, Text, Rect, EvasLoadError, \
+     Image, FilledImage, Gradient, Polygon, Text, Textblock, Rect, EvasLoadError, \
      shutdown, render_method_lookup, render_method_list, \
+     async_events_fd_get, async_events_process, \
      color_argb_premul, color_argb_unpremul, color_parse, \
      color_rgb_to_hsv, color_hsv_to_rgb, image_mask_fill
 
+EVAS_HINT_EXPAND = 1.0
+EVAS_HINT_FILL = -1.0
 
 EVAS_CALLBACK_MOUSE_IN = 0
 EVAS_CALLBACK_MOUSE_OUT = 1
@@ -32,17 +35,27 @@ EVAS_CALLBACK_MOUSE_DOWN = 2
 EVAS_CALLBACK_MOUSE_UP = 3
 EVAS_CALLBACK_MOUSE_MOVE = 4
 EVAS_CALLBACK_MOUSE_WHEEL = 5
-EVAS_CALLBACK_FREE = 6
-EVAS_CALLBACK_KEY_DOWN = 7
-EVAS_CALLBACK_KEY_UP = 8
-EVAS_CALLBACK_FOCUS_IN = 9
-EVAS_CALLBACK_FOCUS_OUT = 10
-EVAS_CALLBACK_SHOW = 11
-EVAS_CALLBACK_HIDE = 12
-EVAS_CALLBACK_MOVE = 13
-EVAS_CALLBACK_RESIZE = 14
-EVAS_CALLBACK_RESTACK = 15
-EVAS_CALLBACK_DEL = 16
+EVAS_CALLBACK_MULTI_DOWN = 6
+EVAS_CALLBACK_MULTI_UP = 7
+EVAS_CALLBACK_MULTI_MOVE = 8
+EVAS_CALLBACK_FREE = 9
+EVAS_CALLBACK_KEY_DOWN = 10
+EVAS_CALLBACK_KEY_UP = 11
+EVAS_CALLBACK_FOCUS_IN = 12
+EVAS_CALLBACK_FOCUS_OUT = 13
+EVAS_CALLBACK_SHOW = 14
+EVAS_CALLBACK_HIDE = 15
+EVAS_CALLBACK_MOVE = 16
+EVAS_CALLBACK_RESIZE = 17
+EVAS_CALLBACK_RESTACK = 18
+EVAS_CALLBACK_DEL = 19
+EVAS_CALLBACK_HOLD = 20
+EVAS_CALLBACK_CHANGED_SIZE_HINTS = 21
+EVAS_CALLBACK_IMAGE_PRELOADED = 22
+EVAS_CALLBACK_CANVAS_FOCUS_IN = 23
+EVAS_CALLBACK_CANVAS_FOCUS_OUT = 24
+EVAS_CALLBACK_RENDER_FLUSH_PRE = 25
+EVAS_CALLBACK_RENDER_FLUSH_POST = 26
 
 EVAS_BUTTON_NONE = 0
 EVAS_BUTTON_DOUBLE_CLICK = 1
@@ -102,4 +115,10 @@ EVAS_IMAGE_ROTATE_90 = 1
 EVAS_IMAGE_ROTATE_180 = 2
 EVAS_IMAGE_ROTATE_270 = 3
 
+EVAS_ASPECT_CONTROL_NONE = 0
+EVAS_ASPECT_CONTROL_NEITHER = 1
+EVAS_ASPECT_CONTROL_HORIZONTAL = 2
+EVAS_ASPECT_CONTROL_VERTICAL = 3
+EVAS_ASPECT_CONTROL_BOTH = 4
+
 c_evas.init()
