@@ -6,7 +6,7 @@
 #define __PYX_EXTERN_C extern
 #endif
 
-/* "include/evas/c_evas.pxd":585
+/* "include/evas/c_evas.pxd":868
  * 
  * 
  * cdef public class Rect [object PyEvasRect, type PyEvasRect_Type]:             # <<<<<<<<<<<<<<
@@ -26,21 +26,22 @@ struct PyEvasRect {
   int _h;
 };
 
-/* "include/evas/c_evas.pxd":684
+/* "include/evas/c_evas.pxd":1018
  * 
  * 
  * cdef public class Canvas [object PyEvasCanvas, type PyEvasCanvas_Type]:             # <<<<<<<<<<<<<<
  *     cdef Evas *obj
- * 
+ *     cdef object _callbacks
  */
 
 struct PyEvasCanvas {
   PyObject_HEAD
   struct __pyx_vtabstruct_4evas_6c_evas_Canvas *__pyx_vtab;
   Evas *obj;
+  PyObject *_callbacks;
 };
 
-/* "include/evas/c_evas.pxd":691
+/* "include/evas/c_evas.pxd":1026
  * 
  * 
  * cdef public class Object [object PyEvasObject, type PyEvasObject_Type]:             # <<<<<<<<<<<<<<
@@ -57,7 +58,7 @@ struct PyEvasObject {
   PyObject *_callbacks;
 };
 
-/* "include/evas/c_evas.pxd":701
+/* "include/evas/c_evas.pxd":1036
  * 
  * 
  * cdef public class SmartObject(Object) [object PyEvasSmartObject,             # <<<<<<<<<<<<<<
@@ -76,9 +77,10 @@ struct PyEvasSmartObject {
   PyObject *_m_color_set;
   PyObject *_m_clip_set;
   PyObject *_m_clip_unset;
+  PyObject *_m_calculate;
 };
 
-/* "include/evas/c_evas.pxd":714
+/* "include/evas/c_evas.pxd":1050
  * 
  * 
  * cdef public class Rectangle(Object) [object PyEvasRectangle,             # <<<<<<<<<<<<<<
@@ -90,7 +92,7 @@ struct PyEvasRectangle {
   struct PyEvasObject __pyx_base;
 };
 
-/* "include/evas/c_evas.pxd":719
+/* "include/evas/c_evas.pxd":1055
  * 
  * 
  * cdef public class Line(Object) [object PyEvasLine, type PyEvasLine_Type]:             # <<<<<<<<<<<<<<
@@ -102,7 +104,7 @@ struct PyEvasLine {
   struct PyEvasObject __pyx_base;
 };
 
-/* "include/evas/c_evas.pxd":723
+/* "include/evas/c_evas.pxd":1059
  * 
  * 
  * cdef public class Image(Object) [object PyEvasImage, type PyEvasImage_Type]:             # <<<<<<<<<<<<<<
@@ -114,7 +116,7 @@ struct PyEvasImage {
   struct PyEvasObject __pyx_base;
 };
 
-/* "include/evas/c_evas.pxd":727
+/* "include/evas/c_evas.pxd":1063
  * 
  * 
  * cdef public class FilledImage(Image) [object PyEvasFilledImage,             # <<<<<<<<<<<<<<
@@ -126,7 +128,7 @@ struct PyEvasFilledImage {
   struct PyEvasImage __pyx_base;
 };
 
-/* "include/evas/c_evas.pxd":732
+/* "include/evas/c_evas.pxd":1068
  * 
  * 
  * cdef public class Gradient(Object) [object PyEvasGradient,             # <<<<<<<<<<<<<<
@@ -138,7 +140,7 @@ struct PyEvasGradient {
   struct PyEvasObject __pyx_base;
 };
 
-/* "include/evas/c_evas.pxd":737
+/* "include/evas/c_evas.pxd":1073
  * 
  * 
  * cdef public class Polygon(Object) [object PyEvasPolygon,             # <<<<<<<<<<<<<<
@@ -150,7 +152,7 @@ struct PyEvasPolygon {
   struct PyEvasObject __pyx_base;
 };
 
-/* "include/evas/c_evas.pxd":742
+/* "include/evas/c_evas.pxd":1078
  * 
  * 
  * cdef public class Text(Object) [object PyEvasText, type PyEvasText_Type]:             # <<<<<<<<<<<<<<
@@ -162,7 +164,19 @@ struct PyEvasText {
   struct PyEvasObject __pyx_base;
 };
 
-/* "include/evas/c_evas.pxd":746
+/* "include/evas/c_evas.pxd":1081
+ *     pass
+ * 
+ * cdef public class Textblock(Object) [object PyEvasTextblock, type PyEvasTextblock_Type]:             # <<<<<<<<<<<<<<
+ *     pass
+ * 
+ */
+
+struct PyEvasTextblock {
+  struct PyEvasObject __pyx_base;
+};
+
+/* "include/evas/c_evas.pxd":1085
  * 
  * 
  * cdef public class ClippedSmartObject(SmartObject) \             # <<<<<<<<<<<<<<
@@ -188,6 +202,7 @@ __PYX_EXTERN_C DL_IMPORT(PyTypeObject) PyEvasFilledImage_Type;
 __PYX_EXTERN_C DL_IMPORT(PyTypeObject) PyEvasGradient_Type;
 __PYX_EXTERN_C DL_IMPORT(PyTypeObject) PyEvasPolygon_Type;
 __PYX_EXTERN_C DL_IMPORT(PyTypeObject) PyEvasText_Type;
+__PYX_EXTERN_C DL_IMPORT(PyTypeObject) PyEvasTextblock_Type;
 __PYX_EXTERN_C DL_IMPORT(PyTypeObject) PyEvasClippedSmartObject_Type;
 
 #endif
