@@ -4,9 +4,10 @@ import unittest
 
 class PolygonBasics(unittest.TestCase):
     def setUp(self):
-        self.canvas = evas.Canvas(method="software_x11",
+        self.canvas = evas.Canvas(method="buffer",
                                   size=(400, 500),
                                   viewport=(0, 0, 400, 500))
+        self.canvas.engine_info_set(self.canvas.engine_info_get())
 
     def tearDown(self):
         del self.canvas
@@ -23,6 +24,5 @@ class PolygonBasics(unittest.TestCase):
         self.assertEqual(o.color, (255, 0, 0, 255))
 
 
-evas.init()
 unittest.main()
 evas.shutdown()
